import{j as t,i as a}from"./index-nQTX7hqb.js";function n({className:r,type:e,...i}){return t.jsx("input",{type:e,"data-slot":"input",className:a("file:text-foreground placeholder:text-muted-foreground selection:bg-primary selection:text-primary-foreground dark:bg-input/30 border-input h-9 w-full min-w-0 rounded-md border bg-transparent px-3 py-1 text-base shadow-xs transition-[color,box-shadow] outline-none file:inline-flex file:h-7 file:border-0 file:bg-transparent file:text-sm file:font-medium disabled:pointer-events-none disabled:cursor-not-allowed disabled:opacity-50 md:text-sm","focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px]","aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive",r),...i})}function o({className:r,...e}){return t.jsx("div",{"data-slot":"card",className:a("bg-card text-card-foreground flex flex-col gap-6 rounded-xl border py-6 shadow-sm",r),...e})}function s({className:r,...e}){return t.jsx("div",{"data-slot":"card-header",className:a("@container/card-header grid auto-rows-min grid-rows-[auto_auto] items-start gap-2 px-6 has-data-[slot=card-action]:grid-cols-[1fr_auto] [.border-b]:pb-6",r),...e})}function l({className:r,...e}){return t.jsx("div",{"data-slot":"card-title",className:a("leading-none font-semibold",r),...e})}function c({className:r,...e}){return t.jsx("div",{"data-slot":"card-description",className:a("text-muted-foreground text-sm",r),...e})}function u({className:r,...e}){return t.jsx("div",{"data-slot":"card-content",className:a("px-6",r),...e})}export{o as C,n as I,s as a,u as b,l as c,c as d};
